function [fopt,xopt,gopt,report]=sifoptim(siffile,algo,Stop) 
// The sifoptim function decode the problem given by a '.sif' file,
// built it and runs the optim function on it
  
// siffile:	path of the .sif file
// algo:	'qn' or 'gc' for quasi-Newton or conjugate gradient
// Stop:        parameters controlling the convergence of the algorithm 
//              Stop=[nap,iter,epsg,epsf] (see optim)
  
// fopt:        criterion value at xopt
// xopt:	point found
// gopt:	gradient at xopt
// report:      row vector of 8 strings.
//              [probname,probsize,#constraints,NITER,fopt,normG ,fail,stop]
  
//Authors B. Durand, S. Steer. Copyright INRIA

  // Optimizer settings
  if argn(2)<3 then 
    Stop=[5000;5000;1d-12;1.d-6],
  elseif size(Stop,'*')<>4 then
    error('Third argument must be the vectpr [maxcall,maxiter,gnorm,fnorm]')
  end
  
  if argn(2)<2 then 
    algo='qn',
  else
    algo=convstr(algo)
    if and(algo<>['qn','gc']) then
      error('Second argument must be ''qn'' or ''gc'' ')
    end
  end

  //decoding and compiling 
  NAME=basename(siffile)
  probpath=TMPDIR+'/'+NAME
  if ~isdir(probpath)
    unix_s('mkdir '+probpath)
  end
  sifdecode(siffile,probpath) //routines are created in the Scilab temporary directory
  buildprob(probpath)
  

  //initialize problem routines data structures
  [XSTART,BL,BU] = usetup(probpath+'/OUTSDIF.d');
  N = size(XSTART,'*')
  
  // Optimizer settings
  if argn(2)<3 then 
    Stop=[5000;5000;2*%eps;2*%eps],
  elseif size(Stop,'*')<>4 then
    error('Third argument must be the vectpr [maxcall,maxiter,gnorm,fnorm]')
  end
    
  // Adapt stacksize if necessary
  if algo=='qn' then mem=10*N+N*N/2,else mem=30*N+11;end
  sz=stacksize();r=sz(1)-(sz(2)+mem);
  if r<0 then stacksize(sz(1)+1.5*abs(r)),end
  
  // Handle fixed variables if any
  [NC,fixed,notfixed] = pretreat(BL,BU)
  if (NC == 0) then //No bounds constraints
   [fopt,xopt,gopt]=optim(ucost,XSTART,algo,'ar',Stop(1),Stop(2),Stop(3),Stop(4))
  elseif (fixed~=[]) then // Bounds contraints some are fixed variables
    Xred  = XSTART(notfixed);
    BLred = BL(notfixed);
    BUred = BU(notfixed);
    [fopt,xoptRed,goptRed]=optim(list(ucost_withfixed,fixed,notfixed,BL(fixed)),..
			       'b',BLred,BUred,Xred,algo,'ar',Stop(1),Stop(2),Stop(3),Stop(4));
    // to rebuild the real fvalue and gopt
    xopt(notfixed) = xoptRed;
    xopt(fixed) = BL(fixed);
    [fopt,gopt] = uofg(xopt); 
  else // Bounds contraints
    [fopt,xopt,gopt]=optim(ucost,'b',BL,BU,XSTART,algo,'ar',Stop(1),Stop(2),Stop(3),Stop(4))
  end

  
  //build the report data 
  [time,calls]=ureprt();    
  normG=norm(projected_gradient(xopt,gopt,BL,BU))
  prec=4.5d-6
  fail = (normG/(abs(fopt)+1) > prec);
  if  fail then c='*',else c=' ',end
  report=[NAME,string([N,NC,calls(1),fopt,normG]),c]
  //remove dynamically loaded entry point created by buildprob
  unlink('siftools')
endfunction
